# Change Log

# [0.2.1](https://github.com/arve0/leicacam/tree/0.2.1) (2018-04-05)
[Full Changelog](https://github.com/arve0/leicacam/compare/v0.2.0...0.2.1)

**Merged pull requests:**

- Enhance release procedure [\#10](https://github.com/arve0/leicacam/pull/10) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Clean up setup.py [\#9](https://github.com/arve0/leicacam/pull/9) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add more tests [\#8](https://github.com/arve0/leicacam/pull/8) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Format examples in docs [\#7](https://github.com/arve0/leicacam/pull/7) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Make docs build cleanly and add links [\#6](https://github.com/arve0/leicacam/pull/6) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix readme [\#5](https://github.com/arve0/leicacam/pull/5) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add linters to tox and travis [\#4](https://github.com/arve0/leicacam/pull/4) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update tox and travis [\#3](https://github.com/arve0/leicacam/pull/3) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Clean requirements [\#2](https://github.com/arve0/leicacam/pull/2) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Switch broken pypip.in badges to shields.io [\#1](https://github.com/arve0/leicacam/pull/1) ([movermeyer](https://github.com/movermeyer))

